function ZHD = GZHD(YYYY,DOY,HOD,Lat,Lon,H,ZTD)

% Input parameters:
%
% YYYY:  The year of the epoachs (vector)
% DOY:   The days of the year (vector)
% HOD:   The hours of the day (vector)
% lat:   Ellipsoidal latitude in degree [-90:+90] (scalar, only one station per call is possible)
% lon:   Longitude in degree [-180:180] (scalar, only one station per call is possible)
% H:     Ellipsoidal height in m (scalar, only one station per call is possible)
% ZTD:   The Zenith Total Delay of epoachs (vector)

% Note: The function need to use a matlab internal function - 'geoidheight'

if Lon < 0
    lon = Lon+360;
else
    lon = Lon;
end
N  = geoidheight(Lat, lon, 'EGM2008');
OH = H - N;
g  = 9.780325*sqrt((1+0.00193185*sind(Lat).*sind(Lat))./(1-0.00669435*sind(Lat).*sind(Lat)));
R  = 6378.137*1000./(1.006803-0.006706*sind(Lat).*sind(Lat));
GH = (g/9.80665)*((R*OH)./(R+OH));

load('GZHD.mat');
ZHD = net([YYYY';DOY';HOD';[Lat;Lon;GH]*ones(1,length(YYYY));ZTD']);